@@ -14,11 +14,20 @@ from os.path import join
 from os.path import expanduser
 
 # directory containing prepared metadata of a dataset repository:
-HANDLE_META_DIR = ".datalad"
+DATALAD_DOTDIR = ".datalad"
+# Compatibility: Used at least in the crawler
+# TODO: figure out how to make it possible to issue DeprecationWarning
+# upon use.  Possible way: make consts into a class instance, but then they
+# all must be imported as `from datalad import consts` and as `consts.CONSTANT`
+HANDLE_META_DIR = DATALAD_DOTDIR
 
 # Make use of those in datalad.metadata
-METADATA_DIR = join(HANDLE_META_DIR, 'meta')
-METADATA_FILENAME = 'meta.json'
+OLDMETADATA_DIR = join(DATALAD_DOTDIR, 'meta')
+OLDMETADATA_FILENAME = 'meta.json'
+
+METADATA_DIR = join(DATALAD_DOTDIR, 'metadata')
+DATASET_METADATA_FILE = join(METADATA_DIR, 'dataset.json')
+DATASET_CONFIG_FILE = join(DATALAD_DOTDIR, 'config')
 
 ARCHIVES_SPECIAL_REMOTE = 'datalad-archives'
 DATALAD_SPECIAL_REMOTE = 'datalad'
@@ -34,6 +43,7 @@ DATALAD_SPECIAL_REMOTES_UUIDS = {
 
 ARCHIVES_TEMP_DIR = join(DATALAD_GIT_DIR, 'tmp', 'archives')
 ANNEX_TEMP_DIR = join('.git', 'annex', 'tmp')
+ANNEX_TRANSFER_DIR = join('.git', 'annex', 'transfer')
 
 SEARCH_INDEX_DOTGITDIR = join('datalad', 'search_index')
 
@@ -56,3 +66,6 @@ GIT_SSH_COMMAND = "datalad sshrun"
 
 # magic sha is from `git hash-object -t tree /dev/null`, i.e. from nothing
 PRE_INIT_COMMIT_SHA = '4b825dc642cb6eb9a060e54bf8d69288fbee4904'
+
+# git/datalad configuration item to provide a token for github
+CONFIG_HUB_TOKEN_FIELD = 'hub.oauthtoken'
\ No newline at end of file
