@@ -16,6 +16,7 @@ from datalad.tests.utils import (
     slow
 )
 
+import logging
 import os
 from os.path import join as opj
 from os.path import isdir
@@ -54,6 +55,7 @@ from datalad.tests.utils import assert_result_values_equal
 from datalad.tests.utils import ok_startswith
 from datalad.tests.utils import ok_clean_git
 from datalad.tests.utils import serve_path_via_http
+from datalad.tests.utils import swallow_logs
 from datalad.tests.utils import use_cassette
 from datalad.tests.utils import skip_if_no_network
 from datalad.tests.utils import skip_if
@@ -65,11 +67,25 @@ from ..dataset import Dataset
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
 def test_invalid_args(path, otherpath, alienpath):
+    # source == path
     assert_raises(ValueError, clone, 'Zoidberg', path='Zoidberg')
-    # install to an invalid URL
-    assert_raises(ValueError, clone, 'Zoidberg', path='ssh://mars:Zoidberg')
-    # install to a remote location
-    assert_raises(ValueError, clone, 'Zoidberg', path='ssh://mars/Zoidberg')
+    assert_raises(ValueError, clone, 'ssh://mars/Zoidberg', path='ssh://mars/Zoidberg')
+
+    # "invalid URL" is a valid filepath... and since no clone to remote
+    # is possible - we can just assume that it is the (legit) file path
+    # which is provided, not a URL.  So both below should fail as any
+    # other clone from a non-existing source and not for the reason of
+    # "invalid something".  Behavior is similar to how Git performs - can
+    # clone into a URL-like path.
+
+    # install to an "invalid URL" path
+    res = clone('Zoidberg', path='ssh://mars:Zoidberg', on_failure='ignore')
+    assert_status('error', res)
+
+    # install to a "remote location" path
+    res = clone('Zoidberg', path='ssh://mars/Zoidberg', on_failure='ignore')
+    assert_status('error', res)
+
     # make fake dataset
     ds = create(path)
     assert_raises(IncompleteResultsError, ds.clone, '/higherup.', 'Zoidberg')
@@ -344,3 +360,15 @@ def test_clone_report_permission_issue(tdir):
             message="could not create work tree dir '%s/%s': Permission denied"
                     % (pdir, get_datasets_topdir())
         )
+
+
+@skip_if_no_network
+@with_tempfile
+def test_autoenabled_remote_msg(path):
+    # Verify that no message about a remote not been enabled is displayed
+    # whenever the remote we clone is the  type=git special remote, so the name
+    # of the remote might not match
+    with swallow_logs(new_level=logging.INFO) as cml:
+        res = clone('///repronim/containers', path)
+        assert_status('ok', res)
+        assert_not_in("not auto-enabled", cml.out)
\ No newline at end of file
