@@ -59,7 +59,8 @@ from datalad.utils import _path_
 import logging
 lgr = logging.getLogger('datalad.tests')
 
-def _test_correct_publish(target_path, rootds=False, flat=True):
+
+def assert_publish_with_ui(target_path, rootds=False, flat=True):
 
     paths = [_path_(".git/hooks/post-update")]     # hooks enabled in all datasets
     not_paths = []  # _path_(".git/datalad/metadata")]  # metadata only on publish
@@ -111,6 +112,28 @@ assert_create_sshwebserver = (
 )
 
 
+def assert_postupdate_hooks(path, installed=True, flat=False):
+    """
+    Verify that post-update hook was installed (or not, if installed=False)
+    """
+    from glob import glob
+    if flat:
+        # there is no top level dataset
+        datasets = glob(opj(path, '*'))
+    else:
+        ds = Dataset(path)
+        datasets = [ds.path] + ds.subdatasets(result_xfm='paths', recursive=True, fulfilled=True)
+    for ds_ in datasets:
+        ds_ = Dataset(ds_)
+        hook_path = opj(ds_.path, '.git', 'hooks', 'post-update')
+        if installed:
+            ok_(os.path.exists(hook_path),
+                msg="Missing %s" % hook_path)
+        else:
+            ok_(not os.path.exists(hook_path),
+                msg="%s exists when it shouldn't" % hook_path)
+
+
 @with_tempfile(mkdir=True)
 def test_invalid_call(path):
     with chpwd(path):
@@ -207,7 +230,9 @@ def test_target_ssh_simple(origin, src_path, target_rootpath):
             name="local_target",
             sshurl="ssh://localhost" + target_path,
             publish_by_default='master',
-            existing='replace')
+            existing='replace',
+            ui=True,
+        )
         eq_("ssh://localhost" + urlquote(target_path),
             source.repo.get_remote_url("local_target"))
         ok_(source.repo.get_remote_url("local_target", push=True) is None)
@@ -245,7 +270,7 @@ def test_target_ssh_simple(origin, src_path, target_rootpath):
         eq_("ssh://localhost" + target_path,
             source.repo.get_remote_url("local_target", push=True))
 
-        _test_correct_publish(target_path)
+        assert_publish_with_ui(target_path)
 
         # now, push should work:
         publish(dataset=source, to="local_target")
@@ -346,7 +371,7 @@ def test_target_ssh_recursive(origin, src_path, target_path):
             # raise if git repos were not created
             GitRepo(target_dir, create=False)
 
-            _test_correct_publish(target_dir, rootds=not suffix, flat=flat)
+            assert_publish_with_ui(target_dir, rootds=not suffix, flat=flat)
 
         for repo in [source.repo, sub1.repo, sub2.repo]:
             assert_not_in("local_target", repo.get_remotes())
@@ -375,6 +400,7 @@ def test_target_ssh_recursive(origin, src_path, target_path):
                 ui=True,
                 since=''
             )
+            assert_postupdate_hooks(target_path_, installed=True, flat=flat)
         # so it was created on remote correctly and wasn't just skipped
         assert(Dataset(_path_(target_path_, ('prefix-' if flat else '') + sub3_name)).is_installed())
         publish(dataset=source, to=remote_name, recursive=True, since='') # just a smoke test
@@ -424,6 +450,9 @@ def test_target_ssh_since(origin, src_path, target_path):
     ok_(Dataset(_path_(target_path, 'brandnew2/sub')).is_installed())
     ok_(Dataset(_path_(target_path, 'brandnew2/sub/sub')).is_installed())
 
+    # we installed without web ui - no hooks should be created/enabled
+    assert_postupdate_hooks(_path_(target_path, 'brandnew'), installed=False)
+
 
 @skip_if_on_windows  # create_sibling incompatible with win servers
 @skip_ssh
@@ -465,7 +494,7 @@ def test_replace_and_relative_sshpath(src_path, dst_path):
     ds = Dataset(src_path).create()
     create_tree(ds.path, {'sub.dat': 'lots of data'})
     ds.add('sub.dat')
-    ds.create_sibling(url)
+    ds.create_sibling(url, ui=True)
     published = ds.publish(to='localhost', transfer_data='all')
     assert_result_count(published, 1, path=opj(ds.path, 'sub.dat'))
     # verify that hook runs and there is nothing in stderr
@@ -481,7 +510,9 @@ def test_replace_and_relative_sshpath(src_path, dst_path):
     res = ds.create_sibling(url, on_failure='ignore')
     assert_status('error', res)
     assert_in('already configured', res[0]['message'][0])
-    ds.create_sibling(url, existing='replace')
+    # "Settings" such as UI do not persist, so we specify it again
+    # for the test below depending on it
+    ds.create_sibling(url, existing='replace', ui=True)
     published2 = ds.publish(to='localhost', transfer_data='all')
     assert_result_count(published2, 1, path=opj(ds.path, 'sub.dat'))
 
@@ -501,31 +532,44 @@ def test_replace_and_relative_sshpath(src_path, dst_path):
     logs_post = glob(_path_(dst_path, WEB_META_LOG, '*'))
     eq_(len(logs_post), len(logs_prior) + 1)
 
+    assert_postupdate_hooks(dst_path)
+
 
 @known_failure_direct_mode  #FIXME
-@skip_if_on_windows  # create_sibling incompatible with win servers
 @skip_ssh
 @with_tempfile(mkdir=True)
 @with_tempfile(suffix="target")
-def _test_target_ssh_inherit(standardgroup, src_path, target_path):
+def _test_target_ssh_inherit(standardgroup, ui, src_path, target_path):
     ds = Dataset(src_path).create()
     target_url = 'localhost:%s' % target_path
     remote = "magical"
     # for the test of setting a group, will just smoke test while using current
     # user's group
-    ds.create_sibling(target_url, name=remote, shared='group', group=os.getgid())  # not doing recursively
+    ds.create_sibling(target_url, name=remote, shared='group', group=os.getgid(), ui=ui)  # not doing recursively
     if standardgroup:
         ds.repo.set_preferred_content('wanted', 'standard', remote)
         ds.repo.set_preferred_content('group', standardgroup, remote)
     ds.publish(to=remote)
 
-    # now a month later we created a new subdataset
-    subds = ds.create('sub')  # so now we got a hierarchy!
-    create_tree(subds.path, {'sub.dat': 'lots of data'})
-    subds.add('sub.dat')
-    ok_file_under_git(subds.path, 'sub.dat', annexed=True)
+    # now a month later we created a new subdataset... a few of the nested ones
+    # A known hiccup happened when there
+    # is also subsub ds added - we might incorrectly traverse and not prepare
+    # sub first for subsub to inherit etc
+    parent_ds = ds
+    subdss = []
+    nlevels = 2  # gets slow: 1 - 43 sec, 2 - 49 sec , 3 - 69 sec
+    for levels in range(nlevels):
+        subds = parent_ds.create('sub')
+        create_tree(subds.path, {'sub.dat': 'lots of data'})
+        subds.add('sub.dat', ds2super=True)
+        ok_file_under_git(subds.path, 'sub.dat', annexed=True)
+        parent_ds = subds
+        subdss.append(subds)
 
-    target_sub = Dataset(opj(target_path, 'sub'))
+    target_subdss = [
+        Dataset(opj(*([target_path] + ['sub'] * (i+1))))
+        for i in range(nlevels)
+    ]
     # since we do not have yet/thus have not used an option to record to publish
     # to that sibling by default (e.g. --set-upstream), if we run just ds.publish
     # -- should fail
@@ -536,35 +580,61 @@ def _test_target_ssh_inherit(standardgroup, src_path, target_path):
         message='No target sibling configured for default publication, please specific via --to')
     ds.publish(to=remote)  # should be ok, non recursive; BUT it (git or us?) would
                   # create an empty sub/ directory
-    ok_(not target_sub.is_installed())  # still not there
+    assert_postupdate_hooks(target_path, installed=ui)
+    for target_sub in target_subdss:
+        ok_(not target_sub.is_installed())  # still not there
     res = ds.publish(to=remote, recursive=True, on_failure='ignore')
-    assert_result_count(res, 2)
+    assert_result_count(res, 1 + len(subdss))
     assert_status(('error', 'notneeded'), res)
     assert_result_count(
-        res, 1,
+        res, len(subdss),
         status='error',
         message=("Unknown target sibling '%s' for publication", 'magical'))
+
+    # Finally publishing with inheritance
     ds.publish(to=remote, recursive=True, missing='inherit')
-    # we added the remote and set all the
-    eq_(subds.repo.get_preferred_content('wanted', remote), 'standard' if standardgroup else '')
-    eq_(subds.repo.get_preferred_content('group', remote), standardgroup or '')
+    assert_postupdate_hooks(target_path, installed=ui)
 
-    ok_(target_sub.is_installed())  # it is there now
-    eq_(target_sub.repo.config.get('core.sharedrepository'), '1')
-    # and we have transferred the content
-    if standardgroup and standardgroup == 'backup':
-        # only then content should be copied
-        ok_file_has_content(opj(target_sub.path, 'sub.dat'), 'lots of data')
-    else:
-        # otherwise nothing is copied by default
-        assert_false(target_sub.repo.file_has_content('sub.dat'))
+    def check_dss():
+        # we added the remote and set all the
+        for subds in subdss:
+            eq_(subds.repo.get_preferred_content('wanted', remote), 'standard' if standardgroup else '')
+            eq_(subds.repo.get_preferred_content('group', remote), standardgroup or '')
+
+        for target_sub in target_subdss:
+            ok_(target_sub.is_installed())  # it is there now
+            eq_(target_sub.repo.config.get('core.sharedrepository'), '1')
+            # and we have transferred the content
+            if standardgroup and standardgroup == 'backup':
+                # only then content should be copied
+                ok_file_has_content(opj(target_sub.path, 'sub.dat'), 'lots of data')
+            else:
+                # otherwise nothing is copied by default
+                assert_false(target_sub.repo.file_has_content('sub.dat'))
+
+    check_dss()
+    # and it should be ok to reconfigure the full hierarchy of datasets
+    # while "inheriting". No URL must be specified, and we must not blow
+    # but just issue a warning for the top level dataset which has no super,
+    # so cannot inherit anything - use case is to fixup/establish the full
+    # hierarchy on the remote site
+    with swallow_logs(logging.WARNING) as cml:
+        out = ds.create_sibling(
+            None, name=remote, existing="reconfigure", inherit=True,
+            ui=ui, recursive=True)
+        eq_(len(out), 1 + len(subdss))
+        assert_in("Cannot determine super dataset", cml.out)
+
+    check_dss()
 
 
+@slow  # 49 sec
 def test_target_ssh_inherit():
     skip_if_on_windows()  # create_sibling incompatible with win servers
     # TODO: was waiting for resolution on
     #   https://github.com/datalad/datalad/issues/1274
     # which is now closed but this one is failing ATM, thus leaving as TODO
     # yield _test_target_ssh_inherit, None      # no wanted etc
-    yield _test_target_ssh_inherit, 'manual'  # manual -- no load should be annex copied
-    yield _test_target_ssh_inherit, 'backup'  # backup -- all data files
+    # Takes too long so one will do with UI and another one without
+    yield _test_target_ssh_inherit, 'manual', True  # manual -- no load should be annex copied
+    yield _test_target_ssh_inherit, 'backup', False  # backup -- all data files
