@@ -35,7 +35,7 @@ from datalad.tests.utils import assert_is
 from datalad.tests.utils import assert_not_equal
 
 from datalad.support.exceptions import InsufficientArgumentsError
-from datalad.support.exceptions import PathOutsideRepositoryError
+from datalad.support.exceptions import PathKnownToRepositoryError
 
 
 def test_EnsureDataset():
@@ -87,8 +87,6 @@ def test_resolve_path(somedir):
 # TODO: test remember/recall more extensive?
 
 
-# TODO: There's something wrong with the nested testrepo!
-# Fear mongering detected!
 @with_testrepos('submodule_annex')
 @with_tempfile(mkdir=True)
 def test_is_installed(src, path):
@@ -101,7 +99,16 @@ def test_is_installed(src, path):
     # submodule still not installed:
     subds = Dataset(opj(path, 'subm 1'))
     assert_false(subds.is_installed())
-    subds.create()
+    # We must not be able to create a new repository under a known
+    # subdataset path.
+    # Note: Unfortunately we would still be able to generate it under
+    # subdirectory within submodule, e.g. `subm 1/subdir` but that is
+    # not checked here. `rev-create` will provide that protection
+    # when create/rev-create merge.
+    # Unfortunately such protection does not work in direct mode
+    if not ds.repo.is_direct_mode():
+        with assert_raises(PathKnownToRepositoryError):
+            subds.create()
     # get the submodule
     # This would init so there is a .git file with symlink info, which is
     # as we agreed is more pain than gain, so let's use our install which would
