@@ -62,10 +62,13 @@ from datalad.utils import (
     as_unicode,
 )
 from datalad.ui import ui
-from datalad.dochelpers import exc_str
+from datalad.dochelpers import (
+    exc_str,
+    single_or_plural,
+)
 from datalad.consts import (
-    METADATA_DIR,
-    METADATA_FILENAME,
+    OLDMETADATA_DIR,
+    OLDMETADATA_FILENAME,
 )
 from datalad.log import log_progress
 
@@ -476,6 +479,18 @@ def _get_metadata(ds, types, global_meta=None, content_meta=None, paths=None):
     from pkg_resources import iter_entry_points  # delayed heavy import
     extractors = {ep.name: ep for ep in iter_entry_points('datalad.metadata.extractors')}
 
+    # we said that we want to fail, rather then just moan about less metadata
+    # Do an early check if all extractors are available so not to wait hours
+    # and then crash for some obvious reason
+    absent_extractors = [t for t in types if t not in extractors]
+    if absent_extractors:
+        raise ValueError(
+            '%d enabled metadata extractor%s not available in this installation'
+            ': %s' %
+            (len(absent_extractors),
+             single_or_plural(" is", "s are", len(absent_extractors)),
+             ', '.join(absent_extractors)))
+
     log_progress(
         lgr.info,
         'metadataextractors',
@@ -492,16 +507,6 @@ def _get_metadata(ds, types, global_meta=None, content_meta=None, paths=None):
             'Engage %s metadata extractor', mtype_key,
             update=1,
             increment=True)
-        if mtype_key not in extractors:
-            # we said that we want to fail, rather then just moan about less metadata
-            log_progress(
-                lgr.error,
-                'metadataextractors',
-                'Failed %s metadata extraction from %s', mtype_key, ds,
-            )
-            raise ValueError(
-                'Enabled metadata extractor %s is not available in this installation',
-                mtype_key)
         try:
             extractor_cls = extractors[mtype_key].load()
             extractor = extractor_cls(
@@ -515,9 +520,8 @@ def _get_metadata(ds, types, global_meta=None, content_meta=None, paths=None):
             )
             raise ValueError(
                 "Failed to load metadata extractor for '%s', "
-                "broken dataset configuration (%s)?: %s",
-                mtype, ds, exc_str(e))
-            continue
+                "broken dataset configuration (%s)?: %s" %
+                (mtype, ds, exc_str(e)))
         try:
             dsmeta_t, contentmeta_t = extractor.get_metadata(
                 dataset=global_meta if global_meta is not None else ds.config.obtain(
@@ -759,7 +763,7 @@ class ReadOnlyDict(Mapping):
         return self._hash
 
 
-def get_ds_aggregate_db_locations(ds, version='default'):
+def get_ds_aggregate_db_locations(ds, version='default', warn_absent=True):
     """Returns the location of a dataset's aggregate metadata DB
 
     Parameters
@@ -770,6 +774,10 @@ def get_ds_aggregate_db_locations(ds, version='default'):
       DataLad aggregate metadata layout version. At the moment only a single
       version exists. 'default' will return the locations for the current default
       layout version.
+    warn_absent : bool
+      If True, warn if the desired DB version is not present and give hints on
+      what else is available. This is useful when using this function from
+      a user-facing command.
 
     Returns
     -------
@@ -789,16 +797,16 @@ def get_ds_aggregate_db_locations(ds, version='default'):
     info_fpath = op.join(ds.path, agginfo_relpath)
     agg_base_path = op.dirname(info_fpath)
     # not sure if this is the right place with these check, better move then to a higher level
-    if not op.exists(info_fpath):
+    if warn_absent and not op.exists(info_fpath):
         if version == 'default':
             # caller had no specific idea what metadata version is needed/available
             # This dataset does not have aggregated metadata.  Does it have any
             # other version?
-            info_glob = agginfo_relpath_template.format('*')
+            info_glob = op.join(ds.path, agginfo_relpath_template).format('*')
             info_files = glob.glob(info_glob)
             msg = "Found no aggregated metadata info file %s." \
                   % info_fpath
-            old_metadata_file = op.join(ds.path, METADATA_DIR, METADATA_FILENAME)
+            old_metadata_file = op.join(ds.path, OLDMETADATA_DIR, OLDMETADATA_FILENAME)
             if op.exists(old_metadata_file):
                 msg += " Found metadata generated with pre-0.10 version of " \
                        "DataLad, but it will not be used."
@@ -815,7 +823,7 @@ def get_ds_aggregate_db_locations(ds, version='default'):
     return info_fpath, agg_base_path
 
 
-def load_ds_aggregate_db(ds, version='default', abspath=False):
+def load_ds_aggregate_db(ds, version='default', abspath=False, warn_absent=True):
     """Load a dataset's aggregate metadata database
 
     Parameters
@@ -826,6 +834,10 @@ def load_ds_aggregate_db(ds, version='default', abspath=False):
       DataLad aggregate metadata layout version. At the moment only a single
       version exists. 'default' will return the content of the current default
       aggregate database version.
+    warn_absent : bool
+      If True, warn if the desired DB version is not present and give hints on
+      what else is available. This is useful when using this function from
+      a user-facing command.
 
     Returns
     -------
@@ -835,7 +847,7 @@ def load_ds_aggregate_db(ds, version='default', abspath=False):
       absolute. If abspath is False, all paths are relative, and the metadata
       object base path is return as a second value.
     """
-    info_fpath, agg_base_path = get_ds_aggregate_db_locations(ds, version)
+    info_fpath, agg_base_path = get_ds_aggregate_db_locations(ds, version, warn_absent)
 
     # save to call even with a non-existing location
     agginfos = _load_json_object(info_fpath)
