@@ -17,7 +17,7 @@ from six.moves import map as map
 def _strip_typerepr(s):
     """Strip away <class '...'> and <type '...'> decorations for docstrings
     """
-    return re.sub("<(class|type) '(\S+)'>", r'\2', s)
+    return re.sub(r"<(class|type) '(\S+)'>", r'\2', s)
 
 
 def _type_str(t):
