@@ -55,6 +55,10 @@ class MissingExternalDependency(RuntimeError):
         return to_str
 
 
+class BrokenExternalDependency(RuntimeError):
+    """Some particular functionality is broken with this dependency."""
+
+
 class DeprecatedError(RuntimeError):
     """To raise whenever a deprecated entirely feature is used"""
     def __init__(self, new=None, version=None, msg=''):
@@ -173,6 +177,12 @@ class PathOutsideRepositoryError(Exception):
         return "path {0} not within repository {1}".format(self.file_, self.repo)
 
 
+class PathKnownToRepositoryError(Exception):
+    """Thrown if file/path is under Git control, and attempted operation
+    must not be ran"""
+    pass
+
+
 class MissingBranchError(Exception):
     """Thrown if accessing a repository's branch, that is not available"""
 
@@ -345,3 +355,19 @@ class CrawlerError(Exception):
 
 class PipelineNotSpecifiedError(CrawlerError):
     pass
+
+
+#
+# Warnings
+#
+
+class DataLadWarning(Warning):
+    pass
+
+
+# We have an exception OutdatedExternalDependency, but it is intended for
+# an instance being raised.  `warnings` module requires a class to be provided
+# as a category, so here is a dedicated Warning class
+class OutdatedExternalDependencyWarning(DataLadWarning):
+    """Warning "category" to use to report about outdated"""
+    pass
\ No newline at end of file
