@@ -37,13 +37,16 @@ from datalad.cmd import Runner
 lgr = logging.getLogger('datalad.support.sshconnector')
 
 
-def get_connection_hash(hostname, port='', username=''):
+def get_connection_hash(hostname, port='', username='', identity_file=''):
     """Generate a hash based on SSH connection properties
 
     This can be used for generating filenames that are unique
     to a connection from and to a particular machine (with
     port and login username). The hash also contains the local
     host name.
+
+    Identity file corresponds to a file that will be passed via ssh's -i
+    option.
     """
     # returning only first 8 characters to minimize our chance
     # of hitting a limit on the max path length for the Unix socket.
@@ -52,10 +55,11 @@ def get_connection_hash(hostname, port='', username=''):
     #  https://github.com/ansible/ansible/issues/11536#issuecomment-153030743
     #  https://github.com/datalad/datalad/pull/1377
     return md5(
-        '{lhost}{rhost}{port}{username}'.format(
+        '{lhost}{rhost}{port}{identity_file}{username}'.format(
             lhost=gethostname(),
             rhost=hostname,
             port=port,
+            identity_file=identity_file,
             username=username).encode('utf-8')).hexdigest()[:8]
 
 
@@ -64,7 +68,7 @@ class SSHConnection(object):
     """Representation of a (shared) ssh connection.
     """
 
-    def __init__(self, ctrl_path, sshri):
+    def __init__(self, ctrl_path, sshri, identity_file=None):
         """Create a connection handler
 
         The actual opening of the connection is performed on-demand.
@@ -76,6 +80,8 @@ class SSHConnection(object):
         sshri: SSHRI
           SSH resource identifier (contains all connection-relevant info),
           or another resource identifier that can be converted into an SSHRI.
+        identity_file : str or None
+          Value to pass to ssh's -i option.
         """
         self._runner = None
 
@@ -91,6 +97,8 @@ class SSHConnection(object):
         if self.sshri.port:
             self._ctrl_options += ['-p', '{}'.format(self.sshri.port)]
 
+        self._identity_file = identity_file
+
         # essential properties of the remote system
         self._remote_props = {}
         self._opened_by_us = False
@@ -207,6 +215,8 @@ class SSHConnection(object):
         ctrl_options = ["-fN",
                         "-o", "ControlMaster=auto",
                         "-o", "ControlPersist=15m"] + self._ctrl_options
+        if self._identity_file:
+            ctrl_options.extend(["-i", self._identity_file])
         # create ssh control master command
         cmd = ["ssh"] + ctrl_options + [self.sshri.as_str()]
 
@@ -339,6 +349,10 @@ class SSHConnection(object):
 class SSHManager(object):
     """Keeps ssh connections to share. Serves singleton representation
     per connection.
+
+    A custom identity file can be specified via `datalad.ssh.identityfile`.
+    Callers are responsible for reloading `datalad.cfg` if they have changed
+    this value since loading datalad.
     """
 
     def __init__(self):
@@ -427,9 +441,13 @@ class SSHManager(object):
             raise ValueError("Unsupported SSH URL: '{0}', use "
                              "ssh://host/path or host:path syntax".format(url))
 
+        from datalad import cfg
+        identity_file = cfg.get("datalad.ssh.identityfile")
+
         conhash = get_connection_hash(
             sshri.hostname,
             port=sshri.port,
+            identity_file=identity_file or "",
             username=sshri.username)
         # determine control master:
         ctrl_path = "%s/%s" % (self.socket_dir, conhash)
@@ -438,7 +456,7 @@ class SSHManager(object):
         if ctrl_path in self._connections:
             return self._connections[ctrl_path]
         else:
-            c = SSHConnection(ctrl_path, sshri)
+            c = SSHConnection(ctrl_path, sshri, identity_file=identity_file)
             self._connections[ctrl_path] = c
             return c
 
