@@ -10,8 +10,7 @@
 """
 
 from mock import patch
-from .utils import ok_startswith, eq_, \
-    ignore_nose_capturing_stdout, assert_cwd_unchanged
+from .utils import ok_startswith, eq_, assert_cwd_unchanged
 
 from datalad.cmd import Runner
 from datalad.support.exceptions import CommandError
@@ -27,7 +26,6 @@ def check_run_and_get_output(cmd):
                              "Exited with %d and output %s" % (e.code, (e.stdout, e.stderr)))
     return output
 
-@ignore_nose_capturing_stdout
 @assert_cwd_unchanged
 def test_run_datalad_help():
     out, err = check_run_and_get_output("datalad --help")
